@@ -1,11 +1,12 @@
-#!/usr/bin/python
+#!/usr/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal_edit as a convenience to use as a script
 from osgeo_utils.gdal_edit import *  # noqa
 from osgeo_utils.gdal_edit import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal_edit')
+deprecation_warn("gdal_edit")
 sys.exit(main(sys.argv))
