@@ -1,11 +1,12 @@
 #!/usr/bin/python3.10
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.pct2rgb as a convenience to use as a script
 from osgeo_utils.pct2rgb import *  # noqa
 from osgeo_utils.pct2rgb import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('pct2rgb')
+deprecation_warn("pct2rgb")
 sys.exit(main(sys.argv))
